@@ -44,6 +44,8 @@ def load_environment(global_conf, app_conf):
     PylonsApp.find_controller = find_controller
     ###### END evil monkey-patch 
 
+    os.environ['CKAN_CONFIG'] = global_conf['__file__']
+
     # Pylons paths
     root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     paths = dict(root=root,
@@ -52,6 +54,7 @@ def load_environment(global_conf, app_conf):
                  templates=[os.path.join(root, 'templates')])
 
     # Initialize config with the basic options
+    
     config.init_app(global_conf, app_conf, package='ckan', paths=paths)
     
     # load all CKAN plugins
@@ -71,8 +74,14 @@ def load_environment(global_conf, app_conf):
     if config.get('ckan.site_id') is None:
         if ':' in ckan_host:
             ckan_host, port = ckan_host.split(':')
+        assert ckan_host, 'You need to configure ckan.site_url or ' \
+                          'ckan.site_id for SOLR search-index rebuild to work.'
         config['ckan.site_id'] = ckan_host
 
+    # Check if SOLR schema is compatible
+    from ckan.lib.search import check_solr_schema_version
+    check_solr_schema_version()
+
     config['routes.map'] = make_map()
     config['pylons.app_globals'] = app_globals.Globals()
     config['pylons.h'] = ckan.lib.helpers
