@@ -7,7 +7,9 @@ from ckan.lib.base import BaseController, response, c, _, gettext, request
 from ckan.lib.helpers import json, date_str_to_datetime
 import ckan.model as model
 import ckan.rating
-from ckan.lib.search import query_for, QueryOptions, SearchIndexError, SearchError, DEFAULT_OPTIONS, convert_legacy_parameters_to_solr
+from ckan.lib.search import (query_for, QueryOptions, SearchIndexError, SearchError,
+                             SearchQueryError, DEFAULT_OPTIONS,
+                             convert_legacy_parameters_to_solr)
 from ckan.plugins import PluginImplementations, IGroupController
 from ckan.lib.navl.dictization_functions import DataError
 from ckan.logic import get_action, check_access
@@ -133,6 +135,7 @@ class ApiController(BaseController):
     def action(self, logic_function):
         function = get_action(logic_function)
         if not function:
+            log.error('Can\'t find logic function: %s' % logic_function)
             return self._finish_bad_request(
                 gettext('Action name not known: %s') % str(logic_function))
         
@@ -142,17 +145,25 @@ class ApiController(BaseController):
         try:
             request_data = self._get_request_data()
         except ValueError, inst:
-
+            log.error('Bad request data: %s' % str(inst))
             return self._finish_bad_request(
                 gettext('JSON Error: %s') % str(inst))
+        if not isinstance(request_data, dict):
+            # this occurs if request_data is blank
+            log.error('Bad request data - not dict: %r' % request_data)
+            return self._finish_bad_request(
+                gettext('Bad request data: %s') % \
+                'Request data JSON decoded to %r but ' \
+                'it needs to be a dictionary.' % request_data)
         try:
             result = function(context, request_data)
             return_dict['success'] = True
             return_dict['result'] = result
-        except DataError:
-            log.error('Format incorrect: %s' % request_data)
+        except DataError, e:
+            log.error('Format incorrect: %s - %s' % (e.error, request_data))
             #TODO make better error message
-            return self._finish(400, _(u'Integrity Error') % request_data)
+            return self._finish(400, _(u'Integrity Error') + \
+                                ': %s - %s' %  (e.error, request_data))
         except NotAuthorized:
             return_dict['error'] = {'__type': 'Authorization Error',
                                     'message': _('Access denied')}
@@ -170,6 +181,16 @@ class ApiController(BaseController):
             return_dict['success'] = False
             log.error('Validation error: %r' % str(e.error_dict))
             return self._finish(409, return_dict, content_type='json')
+        except SearchQueryError, e:
+            return_dict['error'] = {'__type': 'Search Query Error',
+                                    'message': 'Search Query is invalid: %r' % e.args }
+            return_dict['success'] = False
+            return self._finish(400, return_dict, content_type='json')        
+        except SearchError, e:
+            return_dict['error'] = {'__type': 'Search Error',
+                                    'message': 'Search error: %r' % e.args }
+            return_dict['success'] = False
+            return self._finish(409, return_dict, content_type='json')        
         return self._finish_ok(return_dict)
 
     def list(self, ver=None, register=None, subregister=None, id=None):
@@ -284,13 +305,17 @@ class ApiController(BaseController):
                                    resource_location=location)
         except NotAuthorized:
             return self._finish_not_authz()
+        except NotFound, e:
+            extra_msg = e.extra_msg
+            return self._finish_not_found(extra_msg)
         except ValidationError, e:
             log.error('Validation error: %r' % str(e.error_dict))
             return self._finish(409, e.error_dict, content_type='json')
-        except DataError:
-            log.error('Format incorrect: %s' % request_data)
+        except DataError, e:
+            log.error('Format incorrect: %s - %s' % (e.error, request_data))
             #TODO make better error message
-            return self._finish(400, _(u'Integrity Error') % request_data)
+            return self._finish(400, _(u'Integrity Error') + \
+                                ': %s - %s' %  (e.error, request_data))
         except SearchIndexError:
             log.error('Unable to add package to search index: %s' % request_data)
             return self._finish(500, _(u'Unable to add package to search index') % request_data)
@@ -339,10 +364,11 @@ class ApiController(BaseController):
         except ValidationError, e:
             log.error('Validation error: %r' % str(e.error_dict))
             return self._finish(409, e.error_dict, content_type='json')
-        except DataError:
-            log.error('Format incorrect: %s' % request_data)
+        except DataError, e:
+            log.error('Format incorrect: %s - %s' % (e.error, request_data))
             #TODO make better error message
-            return self._finish(400, _(u'Integrity Error') % request_data)
+            return self._finish(400, _(u'Integrity Error') + \
+                                ': %s - %s' %  (e.error, request_data))
         except SearchIndexError:
             log.error('Unable to update search index: %s' % request_data)
             return self._finish(500, _(u'Unable to update search index') % request_data)
