@@ -76,9 +76,10 @@ class UserController(BaseController):
         c.page = h.Page(
             collection=users_list,
             page=page,
+            url=h.pager_url,
             item_count=users_list.count(),
             items_per_page=LIMIT
-            )
+        )
         return render('user/list.html')
 
     def read(self, id=None):
@@ -259,7 +260,8 @@ class UserController(BaseController):
             h.flash_success(_("%s is now logged in") % user_dict['display_name'])
             return self.me()
         else:
-            h.flash_error('Login failed. Bad username or password.')
+            h.flash_error('Login failed. Bad username or password.' + \
+                          ' (Or if using OpenID, it hasn\'t been associated with a user account.)')
             h.redirect_to(controller='user', action='login')
           
     def logged_out(self):
