@@ -25,11 +25,6 @@ import ckan.lib.helpers as h
 from ckan.plugins import PluginImplementations, IGenshiStreamFilter
 from ckan.lib.helpers import json
 import ckan.model as model
-from ckan.lib.cache import etag_cache
-
-# nuke cache
-#from pylons import cache
-#cache.clear()
 
 PAGINATE_ITEMS_PER_PAGE = 50
 
@@ -39,7 +34,7 @@ APIKEY_HEADER_NAME_DEFAULT = 'X-CKAN-API-Key'
 ALLOWED_FIELDSET_PARAMS = ['package_form', 'restrict']
 
 def abort(status_code=None, detail='', headers=None, comment=None):
-    if detail:
+    if detail and status_code!=503:
         h.flash_error(detail)
     # #1267 Convert detail to plain text, since WebOb 0.9.7.1 (which comes
     # with Lucid) causes an exception when unicode is received.
@@ -187,12 +182,13 @@ class BaseController(WSGIController):
             try:
                 request_data = json.loads(request_data, encoding='utf8')
             except ValueError, e:
-                raise ValueError, 'Error parsing JSON data. ' \
+                raise ValueError, 'Error decoding JSON data. ' \
                                     'Error: %r ' \
-                                    'JSON (Decoded and re-encoded): %r' % \
+                                    'JSON data extracted from the request: %r' % \
                                     (e, request_data)
             if not isinstance(request_data, dict):
-                raise ValueError, "Request params must be in form of a json encoded dictionary."
+                raise ValueError, 'Request data JSON decoded to %r but ' \
+                                  'it needs to be a dictionary.' % request_data
             # ensure unicode values
             for key, val in request_data.items():
                 # if val is str then assume it is ascii, since json converts
