@@ -38,6 +38,8 @@ class CkanCommand(paste.script.command.Command):
             msg = 'No config file supplied'
             raise self.BadCommand(msg)
         self.filename = os.path.abspath(self.options.config)
+        if not os.path.exists(self.filename):
+            raise AssertionError('Config filename %r does not exist.' % self.filename)
         fileConfig(self.filename)
         conf = appconfig('config:' + self.filename)
         load_environment(conf.global_conf, conf.local_conf)
@@ -103,7 +105,7 @@ class ManageDb(CkanCommand):
         elif cmd == 'load':
             self.load(cmd)
         elif cmd == 'load-only':
-            self.load(cmd, only_load=True)
+            self.load(only_load=True)
         elif cmd == 'simple-dump-csv':
             self.simple_dump_csv(cmd)
         elif cmd == 'simple-dump-json':
@@ -124,7 +126,7 @@ class ManageDb(CkanCommand):
         from pylons import config
         url = config['sqlalchemy.url']
         # e.g. 'postgres://tester:pass@localhost/ckantest3'
-        db_details_match = re.match('^\s*(?P<db_type>\w*)://(?P<db_user>\w*):?(?P<db_pass>[^@]*)@(?P<db_host>[^/:]*):?(?P<db_port>[^/]*)/(?P<db_name>[\w.-]*)', url)
+        db_details_match = re.match('^\s*(?P<db_type>\w*)://(?P<db_user>[^:]*):?(?P<db_pass>[^@]*)@(?P<db_host>[^/:]*):?(?P<db_port>[^/]*)/(?P<db_name>[\w.-]*)', url)
         if not db_details_match:
             raise Exception('Could not extract db details from url: %r' % url)
         db_details = db_details_match.groupdict()
@@ -251,7 +253,7 @@ class SearchIndexCommand(CkanCommand):
     '''Creates a search index for all datasets
 
     Usage:
-      search-index rebuild                 - indexes all packages
+      search-index rebuild [package-name]  - reindex package-name if given, if not then rebuild full search index (all packages)
       search-index check                   - checks for packages not indexed
       search-index show {package-name}     - shows index of a package
       search-index clear                   - clears the search index for this ckan instance
@@ -273,7 +275,10 @@ class SearchIndexCommand(CkanCommand):
 
         cmd = self.args[0]        
         if cmd == 'rebuild':
-            rebuild()
+            if len(self.args) > 1:
+                rebuild(self.args[1])
+            else:
+                rebuild()
         elif cmd == 'check':
             check()
         elif cmd == 'show':
@@ -406,14 +411,16 @@ class UserCmd(CkanCommand):
       user                            - lists users
       user list                       - lists users
       user <user-name>                - shows user properties
-      user add <user-name> [<apikey>] - add a user (prompts for password)
+      user add <user-name> [apikey=<apikey>] [password=<password>]
+                                      - add a user (prompts for password if
+                                        not supplied)
       user setpass <user-name>        - set user password (prompts)
       user remove <user-name>         - removes user from users
       user search <query>             - searches for a user name
     '''
     summary = __doc__.split('\n')[0]
     usage = __doc__
-    max_args = 3
+    max_args = 4
     min_args = 0
 
     def command(self):
@@ -505,12 +512,38 @@ class UserCmd(CkanCommand):
             print 'Need name of the user.'
             return
         username = self.args[1]
-        apikey = self.args[2] if len(self.args) > 2 else None
-        password = self.password_prompt()
         user = model.User.by_name(unicode(username))
         if user:
             print 'User "%s" already found' % username
             sys.exit(1)
+
+        # parse args
+        apikey = None
+        password = None
+        args = self.args[2:]
+        if len(args) == 1 and not (args[0].startswith('password') or \
+                                   args[0].startswith('apikey')):
+            # continue to support the old syntax of just supplying
+            # the apikey
+            apikey = args[0]
+        else:
+            # new syntax: password=foo apikey=bar
+            for arg in args:
+                split = arg.find('=')
+                if split == -1:
+                    split = arg.find(' ')
+                    if split == -1:
+                        raise ValueError('Could not parse arg: %r (expected "--<option>=<value>)")' % arg)
+                key, value = arg[:split], arg[split+1:]
+                if key == 'password':
+                    password = value
+                elif key == 'apikey':
+                    apikey = value
+                else:
+                    raise ValueError('Could not parse arg: %r (expected password/apikey argument)' % arg)
+
+        if not password:
+            password = self.password_prompt()
         
         print('Creating user: %r' % username)
 
@@ -540,6 +573,21 @@ class UserCmd(CkanCommand):
         user.delete()
         model.repo.commit_and_remove()
         print('Deleted user: %s' % username)
+
+class Celery(CkanCommand):
+    '''Run celery deamon
+
+    Usage:
+        celeryd
+    '''
+    min_args = 0
+    summary = __doc__.split('\n')[0]
+    usage = __doc__
+
+    def command(self):
+        os.environ['CKAN_CONFIG'] = os.path.abspath(self.options.config)
+        from ckan.lib.celery_app import celery
+        celery.worker_main(argv=['celeryd', '--loglevel=INFO'])
         
 
 class Ratings(CkanCommand):
