@@ -11,7 +11,8 @@ from ckan.lib.helpers import json
 
 ## package save
 
-def group_list_dictize(obj_list, context, sort_key=lambda x:x['display_name']):
+def group_list_dictize(obj_list, context, 
+                       sort_key=lambda x:x['display_name'], reverse=False):
 
     active = context.get('active', True)
 
@@ -28,7 +29,7 @@ def group_list_dictize(obj_list, context, sort_key=lambda x:x['display_name']):
         group_dict['packages'] = len(obj.packages)
 
         result_list.append(group_dict)
-    return sorted(result_list, key=sort_key)
+    return sorted(result_list, key=sort_key, reverse=reverse)
 
 def resource_list_dictize(res_list, context):
 
@@ -154,6 +155,11 @@ def package_dictize(pkg, context):
     q = select([rel_rev]).where(rel_rev.c.object_package_id == pkg.id)
     result = _execute_with_revision(q, rel_rev, context)
     result_dict["relationships_as_object"] = obj_list_dictize(result, context)
+    #isopen
+    # Get an actual Package object, not a PackageRevision
+    pkg_object = model.Package.get(pkg.id)
+    result_dict['isopen'] = pkg_object.isopen if isinstance(pkg_object.isopen,bool) else pkg_object.isopen()
+
     return result_dict
 
 def group_dictize(group, context):
@@ -186,11 +192,15 @@ def user_dictize(user, context):
     del result_dict['password']
     
     result_dict['display_name'] = user.display_name
+    result_dict['email_hash'] = user.email_hash
     result_dict['number_of_edits'] = user.number_of_edits()
     result_dict['number_administered_packages'] = user.number_administered_packages()
 
     return result_dict 
 
+def task_status_dictize(task_status, context):
+    return table_dictize(task_status, context)
+
 ## conversion to api
 
 def group_to_api1(group, context):
@@ -253,10 +263,12 @@ def package_to_api1(pkg, context):
     site_url = config.get('ckan.site_url', None)
     if site_url:
         dictized['ckan_url'] = '%s/dataset/%s' % (site_url, pkg.name)
-    dictized['metadata_modified'] = pkg.metadata_modified.isoformat() \
-        if pkg.metadata_modified else None
-    dictized['metadata_created'] = pkg.metadata_created.isoformat() \
-        if pkg.metadata_created else None
+    metadata_modified = pkg.metadata_modified
+    dictized['metadata_modified'] = metadata_modified.isoformat() \
+        if metadata_modified else None
+    metadata_created = pkg.metadata_created
+    dictized['metadata_created'] = metadata_created.isoformat() \
+        if metadata_created else None
 
     subjects = dictized.pop("relationships_as_subject") 
     objects = dictized.pop("relationships_as_object") 
