@@ -7,15 +7,17 @@ from ckan.lib.helpers import json
 def resource_dict_save(res_dict, context):
     model = context["model"]
     session = context["session"]
-
-    # try to get resource object directly from context, then by ID
-    # if not found, create a new resource object
+    trigger_url_change = False
+    
     id = res_dict.get("id")
-    obj = context.get("resource")
-    if (not obj) and id:
+    obj = None
+    if id:
         obj = session.query(model.Resource).get(id)
     if not obj:
+        new = True
         obj = model.Resource()
+    else:
+        new = False
 
     table = class_mapper(model.Resource).mapped_table
     fields = [field.name for field in table.c]
@@ -26,6 +28,8 @@ def resource_dict_save(res_dict, context):
         if key in ('extras', 'revision_timestamp'):
             continue
         if key in fields:
+            if key == 'url' and not new and obj.url <> value:
+                obj.url_changed = True
             setattr(obj, key, value)
         else:
             # resources save extras directly onto the object, instead
@@ -146,16 +150,19 @@ def package_tag_list_save(tag_dicts, package, context):
             pt.state in ['deleted', 'pending-deleted'] ]
         )
 
+    tag_names = set()
     tags = set()
     for tag_dict in tag_dicts:
-        obj = table_dict_save(tag_dict, model.Tag, context)
-        tags.add(obj)
+        if tag_dict.get('name') not in tag_names:
+            tag_obj = table_dict_save(tag_dict, model.Tag, context)
+            tags.add(tag_obj)
+            tag_names.add(tag_obj.name)
 
     # 3 cases
     # case 1: currently active but not in new list
     for tag in set(tag_package_tag.keys()) - tags:
         package_tag = tag_package_tag[tag]
-        if pending and package_tag.state <> 'deleted':
+        if pending and package_tag.state != 'deleted':
             package_tag.state = 'pending-deleted'
         else:
             package_tag.state = 'deleted'
@@ -332,7 +339,7 @@ def user_dict_save(user_dict, context):
 def package_api_to_dict(api1_dict, context):
 
     package = context.get("package")
-
+    api_version = context.get('api_version') or '1'
     dictized = {}
 
     for key, value in api1_dict.iteritems():
@@ -357,10 +364,14 @@ def package_api_to_dict(api1_dict, context):
                 else:
                     new_value.append({"key": extras_key,
                                       "value": None})
+        if key == 'groups' and len(value):
+            if api_version == '1':
+                new_value = [{'name': item} for item in value]
+            else:
+                new_value = [{'id': item} for item in value]
 
         dictized[key] = new_value
 
-    groups = dictized.pop('groups', None)
     download_url = dictized.pop('download_url', None)
     if download_url and not dictized.get('resources'):
         dictized["resources"] = [{'url': download_url}]
@@ -384,3 +395,12 @@ def group_api_to_dict(api1_dict, context):
 
     return dictized
 
+def task_status_dict_save(task_status_dict, context):
+    model = context["model"]
+    task_status = context.get("task_status")
+    allow_partial_update = context.get("allow_partial_update", False)
+    if task_status:
+        task_status_dict["id"] = task_status.id 
+
+    task_status = table_dict_save(task_status_dict, model.TaskStatus, context)
+    return task_status
