@@ -15,6 +15,7 @@ from webhelpers.markdown import markdown
 from webhelpers import paginate
 from webhelpers.text import truncate
 import webhelpers.date as date
+from pylons import url
 from pylons.decorators.cache import beaker_cache
 from routes import url_for, redirect_to
 from alphabet_paginate import AlphaPage
@@ -195,7 +196,11 @@ def linked_user(user, maxlength=0):
             return user_name
     if user:
         _name = user.name if model.User.VALID_NAME.match(user.name) else user.id
-        _icon = icon("user") + " "
+        # Absolute URL of default user icon
+        from pylons import config 
+        _site_url = config.get('ckan.site_url', '')
+        _icon_url_default = _site_url + icon_url("user")
+        _icon = gravatar(user.email_hash, 16, _icon_url_default)+" "
         displayname = user.display_name
         if maxlength and len(user.display_name) > maxlength:
             displayname = displayname[:maxlength] + '...'
@@ -219,11 +224,28 @@ def markdown_extract(text):
 def icon_url(name):
     return '/images/icons/%s.png' % name
 
+def icon_html(url, alt=None):
+    return literal('<img src="%s" height="16px" width="16px" alt="%s" /> ' % (url, alt))
+
 def icon(name, alt=None):
-    return literal('<img src="%s" height="16px" width="16px" alt="%s" /> ' % (icon_url(name), alt))
+    return icon_html(icon_url(name),alt)
+
+def linked_gravatar(email_hash, size=100, default="mm"):
+    return literal('<a href="http://gravatar.com" target="_blank">%s</a>' % gravatar(email_hash,size,default))
+
+def gravatar(email_hash, size=100, default="mm"):
+    return literal('<img src="http://gravatar.com/avatar/%s?s=%d&amp;d=%s" />' % (email_hash, size, default))
+
+def pager_url(page, partial=None, **kwargs):
+    routes_dict = url.environ['pylons.routes_dict']
+    kwargs['controller'] = routes_dict['controller']
+    kwargs['action'] = routes_dict['action']
+    if routes_dict.get('id'):
+        kwargs['id'] = routes_dict['id']
+    kwargs['page'] = page
+    return url(**kwargs)
 
 class Page(paginate.Page):
-    
     # Curry the pager method of the webhelpers.paginate.Page class, so we have
     # our custom layout set as default.
     def pager(self, *args, **kwargs):
@@ -233,7 +255,6 @@ class Page(paginate.Page):
         )
         return super(Page, self).pager(*args, **kwargs)
 
-
 def render_datetime(datetime_):
     '''Render a datetime object or timestamp string as a pretty string
     (Y-m-d H:m).
