@@ -1,18 +1,24 @@
 from sqlalchemy.sql import select
 from sqlalchemy import or_, and_, func, desc, case
+import uuid
+from pylons import config
 
+import ckan
 from ckan.logic import NotFound
 from ckan.logic import check_access
 from ckan.plugins import (PluginImplementations,
                           IGroupController,
                           IPackageController)
+from pylons import config
 from ckan.authz import Authorizer
 from ckan.lib.dictization import table_dictize
 from ckan.lib.dictization.model_dictize import (package_dictize,
                                                 resource_list_dictize,
+                                                resource_dictize,
                                                 group_dictize,
                                                 group_list_dictize,
                                                 tag_dictize,
+                                                task_status_dictize,
                                                 user_dictize)
 
 from ckan.lib.dictization.model_dictize import (package_to_api1,
@@ -26,6 +32,31 @@ import logging
 
 log = logging.getLogger('ckan.logic')
 
+def _package_list_with_resources(context, package_revision_list):
+    package_list = []
+    model = context["model"]
+    for package in package_revision_list:
+        result_dict = table_dictize(package, context)
+        res_rev = model.resource_revision_table
+        resource_group = model.resource_group_table
+        query = select([res_rev], from_obj = res_rev.join(resource_group,
+                   resource_group.c.id == res_rev.c.resource_group_id))
+        query = query.where(resource_group.c.package_id == package.id)
+        result = query.where(res_rev.c.current == True).execute()
+        result_dict["resources"] = resource_list_dictize(result, context)
+        license_id = result_dict['license_id']
+        if license_id:
+            try:
+                isopen = model.Package.get_license_register()[license_id].isopen()
+                result_dict['isopen'] = isopen
+            except KeyError:
+                # TODO: create a log message this error?
+                result_dict['isopen'] = False
+        else:
+            result_dict['isopen'] = False
+        package_list.append(result_dict)
+    return package_list
+
 def site_read(context,data_dict=None):
     check_access('site_read',context,data_dict)
     return True
@@ -62,28 +93,7 @@ def current_package_list_with_resources(context, data_dict):
     if limit:
         query = query.limit(limit)
     pack_rev = query.all()
-    package_list = []
-    for package in pack_rev:
-        result_dict = table_dictize(package, context)
-        res_rev = model.resource_revision_table
-        resource_group = model.resource_group_table
-        query = select([res_rev], from_obj = res_rev.join(resource_group,
-                   resource_group.c.id == res_rev.c.resource_group_id))
-        query = query.where(resource_group.c.package_id == package.id)
-        result = query.where(res_rev.c.current == True).execute()
-        result_dict["resources"] = resource_list_dictize(result, context)
-        license_id = result_dict['license_id']
-        if license_id:
-            try:
-                isopen = model.Package.get_license_register()[license_id].isopen()
-                result_dict['isopen'] = isopen
-            except KeyError:
-                # TODO: create a log message this error?
-                result_dict['isopen'] = False
-        else:
-            result_dict['isopen'] = False
-        package_list.append(result_dict)
-    return package_list
+    return _package_list_with_resources(context, pack_rev)
 
 def revision_list(context, data_dict):
 
@@ -117,25 +127,30 @@ def group_list(context, data_dict):
     user = context['user']
     api = context.get('api_version') or '1'
     ref_group_by = 'id' if api == '2' else 'name';
-
+    order_by = data_dict.get('order_by', 'name')
+    if order_by not in set(('name', 'packages')):
+        raise ValidationError('"order_by" value %r not implemented.' % order_by)
     all_fields = data_dict.get('all_fields',None)
    
     check_access('group_list',context, data_dict)
 
-    # We need Groups for group_list_dictize
     query = model.Session.query(model.Group).join(model.GroupRevision)
     query = query.filter(model.GroupRevision.state=='active')
     query = query.filter(model.GroupRevision.current==True)
-    query = query.order_by(model.Group.name.asc())
-    query = query.order_by(model.Group.title.asc())
 
+    if order_by == 'name':
+        sort_by, reverse = 'name', False
 
     groups = query.all()
 
+    if order_by == 'packages':
+        sort_by, reverse = 'packages', True
+
     if not all_fields:
         group_list = [getattr(p, ref_group_by) for p in groups]
     else:
-        group_list = group_list_dictize(groups,context)
+        group_list = group_list_dictize(groups, context,
+                                        lambda x:x[sort_by], reverse)
 
     return group_list
 
@@ -145,7 +160,6 @@ def group_list_authz(context, data_dict):
 
     If 'available_only' is specified, the existing groups in the package are
     removed.
-
     '''
     model = context['model']
     user = context['user']
@@ -153,7 +167,6 @@ def group_list_authz(context, data_dict):
 
     check_access('group_list_authz',context, data_dict)
 
-    from ckan.authz import Authorizer
     query = Authorizer().authorized_query(user, model.Group, model.Action.EDIT)
     groups = set(query.all())
     
@@ -338,7 +351,7 @@ def package_show(context, data_dict):
     if pkg is None:
         raise NotFound
 
-    check_access('package_show',context, data_dict)
+    check_access('package_show', context, data_dict)
 
     package_dict = package_dictize(pkg, context)
 
@@ -347,6 +360,20 @@ def package_show(context, data_dict):
 
     return package_dict
 
+def resource_show(context, data_dict):
+    model = context['model']
+    api = context.get('api_version') or '1'
+    id = data_dict['id']
+
+    resource = model.Resource.get(id)
+    context['resource'] = resource
+
+    if not resource:
+        raise NotFound
+
+    check_access('resource_show', context, data_dict)
+
+    return resource_dictize(resource, context)
 
 def revision_show(context, data_dict):
     model = context['model']
@@ -384,6 +411,38 @@ def group_show(context, data_dict):
 
     return group_dict
 
+def group_package_show(context, data_dict):
+    """
+    Shows all packages belonging to a group.
+    """
+    model = context["model"]
+    user = context["user"]
+    id = data_dict['id']
+    limit = data_dict.get("limit")
+
+    group = model.Group.get(id)
+    context['group'] = group
+    if group is None:
+        raise NotFound
+
+    check_access('group_show', context, data_dict)
+
+    query = model.Session.query(model.PackageRevision)\
+        .filter(model.PackageRevision.state=='active')\
+        .filter(model.PackageRevision.current==True)\
+        .join(model.PackageGroup, model.PackageGroup.package_id==model.PackageRevision.id)\
+        .join(model.Group, model.Group.id==model.PackageGroup.group_id)\
+        .filter_by(id=group.id)\
+        .order_by(model.PackageRevision.name)
+
+    if limit:
+        query = query.limit(limit)
+
+    result = []
+    for pkg_rev in query.all():
+        result.append(package_dictize(pkg_rev,context))
+
+    return result
 
 def tag_show(context, data_dict):
     '''Shows tag details'''
@@ -401,9 +460,11 @@ def tag_show(context, data_dict):
     check_access('tag_show',context, data_dict)
 
     tag_dict = tag_dictize(tag,context)
+
     extended_packages = []
     for package in tag_dict['packages']:
-        extended_packages.append(_extend_package_dict(package,context))
+        pkg = model.Package.get(package['id'])
+        extended_packages.append(package_dictize(pkg,context))
 
     tag_dict['packages'] = extended_packages
 
@@ -626,8 +687,7 @@ def package_search(context, data_dict):
             log.warning('package %s in index but not in database' % package)
             continue
 
-        result_dict = table_dictize(pkg, context)
-        result_dict = _extend_package_dict(result_dict,context)
+        result_dict = package_dictize(pkg,context)
         results.append(result_dict)
 
     return {
@@ -739,3 +799,57 @@ def tag_search(context, data_dict):
     q = q.limit(limit)
     results = [r for r in q]
     return {'count': count, 'results': results}
+
+def task_status_show(context, data_dict):
+    model = context['model']
+    id = data_dict.get('id')
+
+    if id:
+        task_status = model.TaskStatus.get(id)
+    else:
+        query = model.Session.query(model.TaskStatus)\
+            .filter(and_(
+                model.TaskStatus.entity_id == data_dict['entity_id'],
+                model.TaskStatus.task_type == data_dict['task_type'],
+                model.TaskStatus.key == data_dict['key']
+            ))
+        task_status = query.first()
+
+    context['task_status'] = task_status
+
+    if task_status is None:
+        raise NotFound
+
+    check_access('task_status_show', context, data_dict)
+
+    task_status_dict = task_status_dictize(task_status, context)
+    return task_status_dict
+
+def get_site_user(context, data_dict):
+    check_access('get_site_user', context, data_dict)
+    model = context['model']
+    site_id = config.get('ckan.site_id', 'ckan_site_user')
+    user = model.User.get(site_id)
+    if not user:
+        apikey = str(uuid.uuid4())
+        user = model.User(name=site_id,
+                          password=apikey,
+                          apikey=apikey)
+        model.add_user_to_role(user, model.Role.ADMIN, model.System())
+        model.Session.add(user)
+        model.Session.flush()
+        if not context.get('defer_commit'):
+            model.Session.commit()
+    return {'name': user.name,
+            'apikey': user.apikey}
+
+def status_show(context, data_dict):
+    '''Provides information about the operation of this CKAN instance.'''
+    return {
+        'site_title': config.get('ckan.site_title'),
+        'site_description': config.get('ckan.site_description'),
+        'site_url': config.get('ckan.site_url'),
+        'ckan_version': ckan.__version__,
+        'error_emails_to': config.get('email_to'),
+        'locale_default': config.get('ckan.locale_default'),
+        }
