@@ -46,3 +46,12 @@ def revision_undelete(context, data_dict):
 def revision_delete(context, data_dict):
     return {'success': False, 'msg': 'Not implemented yet in the auth refactor'}
 
+def task_status_delete(context, data_dict):
+    model = context['model']
+    user = context['user']
+
+    authorized =  Authorizer().is_sysadmin(unicode(user))
+    if not authorized:
+        return {'success': False, 'msg': _('User %s not authorized to delete task_status') % str(user)}
+    else:
+        return {'success': True}
