@@ -108,7 +108,7 @@ def package_name_validator(key, data, errors, context):
     else:
         package_id = data.get(key[:-1] + ("id",))
     if package_id and package_id is not missing:
-        query = query.filter(model.Package.id <> package_id) 
+        query = query.filter(model.Package.id <> package_id)
     result = query.first()
     if result:
         errors[key].append(_('That URL is already in use.'))
@@ -121,12 +121,12 @@ def duplicate_extras_key(key, data, errors, context):
     for extra in extras:
         if not extra.get('deleted'):
             extras_keys.append(extra['key'])
-    
+
     for extra_key in set(extras_keys):
         extras_keys.remove(extra_key)
     if extras_keys:
         errors[key].append(_('Duplicate key "%s"') % extras_keys[0])
-    
+
 def group_name_validator(key, data, errors, context):
     model = context['model']
     session = context['session']
@@ -138,7 +138,7 @@ def group_name_validator(key, data, errors, context):
     else:
         group_id = data.get(key[:-1] + ('id',))
     if group_id and group_id is not missing:
-        query = query.filter(model.Group.id <> group_id) 
+        query = query.filter(model.Group.id <> group_id)
     result = query.first()
     if result:
         errors[key].append(_('Group name already exists in database'))
@@ -198,29 +198,30 @@ def ignore_not_admin(key, data, errors, context):
             authorized = True
         except NotAuthorized:
             authorized = False
-    
+
     if (user and pkg and authorized):
         return
 
     data.pop(key)
 
-def user_name_validator(value,context):
-    model = context['model']
+def user_name_validator(key, data, errors, context):
+    model = context["model"]
+    session = context["session"]
+    user = context.get("user_obj")
 
-    if not model.User.check_name_valid(value):
-        raise Invalid(
-            _('That login name is not valid. It must be at least 3 characters, restricted to alphanumerics and these symbols: %s') % '_\-'
-        )
-
-    if not model.User.check_name_available(value):
-        raise Invalid(
-            _("That login name is not available.")
-        )
-
-    return value
+    query = session.query(model.User.name).filter_by(name=data[key])
+    if user:
+        user_id = user.id
+    else:
+        user_id = data.get(key[:-1] + ("id",))
+    if user_id and user_id is not missing:
+        query = query.filter(model.User.id <> user_id)
+    result = query.first()
+    if result:
+        errors[key].append(_('That login name is not available.'))
 
 def user_both_passwords_entered(key, data, errors, context):
-    
+
     password1 = data.get(('password1',),None)
     password2 = data.get(('password2',),None)
 
@@ -235,7 +236,7 @@ def user_password_validator(key, data, errors, context):
         errors[('password',)].append(_('Your password must be 4 characters or longer'))
 
 def user_passwords_match(key, data, errors, context):
-    
+
     password1 = data.get(('password1',),None)
     password2 = data.get(('password2',),None)
 
@@ -248,7 +249,7 @@ def user_passwords_match(key, data, errors, context):
 def user_password_not_empty(key, data, errors, context):
     '''Only check if password is present if the user is created via action API.
        If not, user_both_passwords_entered will handle the validation'''
-     
+
     if not ('password1',) in data and not ('password2',) in data:
         password = data.get(('password',),None)
         if not password:
