@@ -24,7 +24,7 @@ class MarkdownFormat(TextFormat):
     any_link = re.compile(r'<a[^>]*?>', re.IGNORECASE)
     close_link = re.compile(r'<(\/a[^>]*)>', re.IGNORECASE)
     link_escp = re.compile(r'\\xfc\\xfd(\/?(%s)[^>]*?)\\xfd\\xfc' % "|".join(['a']), re.IGNORECASE)
-    web_address = re.compile(r'(\s|^)((http|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?)', re.IGNORECASE)
+    web_address = re.compile(r'(\s|<p>)((http|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?)', re.IGNORECASE)
     
     def to_html(self, text):
         if text is None:
@@ -32,9 +32,6 @@ class MarkdownFormat(TextFormat):
         # Encode whitelist elements.
         text = self.whitelist_elem.sub(r'\\\\xfc\\\\xfd\1\\\\xfd\\\\xfc', text)
 
-        # Discover external addresses and make them links
-        text = self.web_address.sub(r'\1<\2>', text)
-        
         # Encode links only in an acceptable format (guard against spammers)
         text = self.normal_link.sub(r'\\\\xfc\\\\xfda href="\1" target="_blank" rel="nofollow"\\\\xfd\\\\xfc', text)
         text = self.abbrev_link.sub(r'\\\\xfc\\\\xfda href="\1" target="_blank" rel="nofollow"\\\\xfd\\\\xfc\1</a>', text)
@@ -53,6 +50,9 @@ class MarkdownFormat(TextFormat):
         # Markdown to HTML.
         text = webhelpers.markdown.markdown(text, safe_mode=True)
 
+        # Remaining unlinked web addresses to become addresses
+        text = self.web_address.sub(r'\1<a href="\2" target="_blank" rel="nofollow">\2</a>', text)
+
         # Decode whitelist elements.
         text = self.whitelist_escp.sub(r'<\1>', text)
         text = self.link_escp.sub(r'<\1>', text)
