@@ -17,12 +17,12 @@ from user import user_table, User
 from authorization_group import * 
 from group import *
 from group_extra import *
-from search_index import *
 from authz import *
 from package_extra import *
 from resource import *
 from rating import *
 from package_relationship import *
+from task_status import *
 from changeset import Changeset, Change, Changemask
 import ckan.migration
 from ckan.lib.helpers import OrderedDict, datetime_to_date_str
@@ -37,16 +37,17 @@ def init_model(engine):
     '''Call me before using any of the tables or classes in the model'''
     meta.Session.remove()
     meta.Session.configure(bind=engine)
+    meta.create_local_session.configure(bind=engine)
     meta.engine = engine
     meta.metadata.bind = engine
     # sqlalchemy migrate version table
-    import sqlalchemy.exceptions
+    import sqlalchemy.exc
     try:
         version_table = Table('migrate_version', metadata, autoload=True)
-    except sqlalchemy.exceptions.NoSuchTableError:
+    except sqlalchemy.exc.NoSuchTableError:
         pass
 
-
+    
 
 class Repository(vdm.sqlalchemy.Repository):
     migrate_repository = ckan.migration.__path__[0]
@@ -154,13 +155,13 @@ class Repository(vdm.sqlalchemy.Repository):
 
 
     def setup_migration_version_control(self, version=None):
-        import migrate.versioning.exceptions
+        import migrate.exceptions
         import migrate.versioning.api as mig
         # set up db version control (if not already)
         try:
             mig.version_control(self.metadata.bind,
                     self.migrate_repository, version)
-        except migrate.versioning.exceptions.DatabaseAlreadyControlledError:
+        except migrate.exceptions.DatabaseAlreadyControlledError:
             pass
 
     def upgrade_db(self, version=None):
