@@ -9,7 +9,7 @@ from pylons import config
 from meta import metadata, Session
 import vdm.sqlalchemy
 
-from types import make_uuid
+from types import make_uuid, iso_date_to_datetime_for_sqlite
 from core import make_revisioned_table, Revision, State
 from license import License, LicenseRegister
 from domain_object import DomainObject
@@ -189,6 +189,7 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
         # Set 'license' in _dict to cater for old clients.
         # Todo: Remove from Version 2?
         _dict['license'] = self.license.title if self.license else _dict.get('license_id', '')
+        _dict['isopen'] = self.isopen()
         tags = [tag.name for tag in self.tags]
         tags.sort() # so it is determinable
         _dict['tags'] = tags
@@ -453,17 +454,14 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
                         results[key] = value_diff
         return results
 
-    @staticmethod
-    def last_modified(*av):
+    @property
+    def metadata_modified(self):
         """
-        Return most recent timestamp for a package revision, with optionally
-        extra where clause.
+        Return most recent timestamp for revisions related to this package.
+        NB Excludes changes to the package's groups
         """
         from ckan import model
-        where = []
-        for arg in av:
-            if isinstance(arg, expression.ClauseElement) or isinstance(arg, basestring):
-                where.append(arg)
+        where = [model.package_table.c.id == self.id]
         where_clauses = [
             and_(model.package_table.c.revision_id == model.revision_table.c.id, *where),
             and_(model.package_extra_table.c.package_id == model.package_table.c.id,
@@ -481,34 +479,29 @@ class Package(vdm.sqlalchemy.RevisionedObjectMixin,
                  model.package_tag_table.c.revision_id == model.revision_table.c.id, *where)
             ]
         query = union(*[select([model.revision_table.c.timestamp], x) for x in where_clauses]
-                      ).order_by("timestamp DESC").limit(1)
-        conn = model.meta.engine.connect()
+                      ).order_by('timestamp DESC').limit(1)
+        # Use current connection because we might be in a 'before_commit' of
+        # a SessionExtension - only by using the current connection can we get
+        # at the newly created revision etc. objects.
+        conn = model.Session.connection() 
         result = conn.execute(query).fetchone()
         if result:
-            timestamp = result[0].utctimetuple()
-            usecs = float(result[0].microsecond) / 1e6
-        else:
-            timestamp, usecs = gmtime(), 0
-        # use timegm instead of mktime, because we don't want it localised
-        return timegm(timestamp) + usecs
+            result_datetime = iso_date_to_datetime_for_sqlite(result[0])
+            timestamp_without_usecs = result_datetime.utctimetuple()
+            usecs = float(result_datetime.microsecond) / 1e6
+            # use timegm instead of mktime, because we don't want it localised
+            timestamp_float = timegm(timestamp_without_usecs) + usecs
+            return datetime.datetime.utcfromtimestamp(timestamp_float)
 
-    @property
-    def metadata_modified(self):
-        import ckan.model as model
-        epochtime = self.last_modified(model.package_table.c.id==self.id)
-        return datetime.datetime.utcfromtimestamp(epochtime)
-    
     @property
     def metadata_created(self):
         import ckan.model as model
-        q = model.Session.query(model.Revision).select_from(
-            model.revision_table.join(
-                model.package_revision_table,
-                and_(model.revision_table.c.id==model.package_revision_table.c.revision_id))
-            ).order_by(model.Revision.timestamp.asc())
+        q = model.Session.query(model.PackageRevision)\
+            .filter(model.PackageRevision.id == self.id)\
+            .order_by(model.PackageRevision.revision_timestamp.asc())
         ts = q.first()
         if ts is not None:
-            return ts.timestamp
+            return ts.revision_timestamp
 
     @staticmethod
     def get_fields(core_only=False, fields_to_ignore=None):
