@@ -3,7 +3,6 @@ import vdm.sqlalchemy
 import tag
 from core import *
 from package import *
-import search_index
 from ckan.model import extension
 
 __all__ = ['PackageRevision']
@@ -19,9 +18,6 @@ mapper(Package, package_table, properties={
     'package_tags':relation(tag.PackageTag, backref='package',
         cascade='all, delete', #, delete-orphan',
         ),
-    'package_search':relation(search_index.PackageSearch,
-        cascade='all, delete', #, delete-orphan',
-        ),
     },
     order_by=package_table.c.name,
     extension=[vdm.sqlalchemy.Revisioner(package_revision_table),
