@@ -18,6 +18,11 @@
       client: client
     };
 
+    var isFrontPage = $('body.index.home').length > 0;
+    if (isFrontPage) {
+      CKAN.Utils.setupWelcomeBanner($('.js-welcome-banner'));
+    }
+
     var isDatasetView = $('body.package.read').length > 0;
     if (isDatasetView) {
       var _dataset = new CKAN.Model.Dataset(preload_dataset);
@@ -85,6 +90,15 @@ CKAN.Utils = function($, my) {
     messageDiv.show(1200);
   };
 
+  // Animate the appearance of an element by expanding its height
+  my.animateHeight = function(element, animTime) {
+    if (!animTime) animTime = 350;
+    element.show();
+    var finalHeight = element.height();
+    element.height(0);
+    element.animate({height:finalHeight}, animTime);
+  }
+
   my.bindInputChanges = function(input, callback) {
     input.keyup(callback);
     input.keydown(callback);
@@ -92,6 +106,20 @@ CKAN.Utils = function($, my) {
     input.change(callback);
   };
 
+  my.setupWelcomeBanner = function(banner) {
+
+    var cookieName = 'ckan_killtopbar';
+    var isKilled = ($.cookie(cookieName)!=null);
+    if (!isKilled) {
+      banner.show();
+      // Bind to the close button
+      banner.find('.js-kill-button').live('click', function() {
+        $.cookie(cookieName, 'true', { expires: 365 });
+        banner.hide();
+      });
+    }
+  };
+
   my.setupUrlEditor = function(slugType,readOnly) {
     // Page elements to hook onto
     var titleInput = $('.js-title');
@@ -100,6 +128,12 @@ CKAN.Utils = function($, my) {
     var urlInput = $('.js-url-input');
     var validMsg = $('.js-url-is-valid');
 
+    if (titleInput.length==0) throw "No titleInput found.";
+    if (urlText.length==0) throw "No urlText found.";
+    if (urlSuffix.length==0) throw "No urlSuffix found.";
+    if (urlInput.length==0) throw "No urlInput found.";
+    if (validMsg.length==0) throw "No validMsg found.";
+
     var api_url = '/api/2/util/is_slug_valid';
     // (make length less than max, in case we need a few for '_' chars to de-clash slugs.)
     var MAX_SLUG_LENGTH = 90;
@@ -159,11 +193,16 @@ CKAN.Utils = function($, my) {
       return function() {
         slug = urlInput.val();
         urlSuffix.html('<span>'+slug+'</span>');
-        validMsg.html('<span style="color: #777;">'+CKAN.Strings.checking+'</span>');
         if (timer) clearTimeout(timer);
-        timer = setTimeout(function () {
-          checkSlugValid(slug);
-        }, 200);
+        if (slug.length<2) {
+          validMsg.html('<span style="font-weight: bold; color: #444;">'+CKAN.Strings.urlIsTooShort+'</span>');
+        }
+        else {
+          validMsg.html('<span style="color: #777;">'+CKAN.Strings.checking+'</span>');
+          timer = setTimeout(function () {
+            checkSlugValid(slug);
+          }, 200);
+        }
       };
     }();
 
@@ -677,7 +716,9 @@ CKAN.View.ResourceAddLink = Backbone.View.extend({
     var dialogId = 'ckanext-datapreview-dialog';
     // initialize the tableviewer system
     DATAEXPLORER.TABLEVIEW.initialize(dialogId);
-    my.createPreviewButtons(dataset, $('.resources'));
+    if (dataset.get('resources').length>0) {
+      my.createPreviewButtons(dataset, $('.resources'));
+    }
   };
 
   // Public: Creates the base UI for the plugin.
